import { GetPermissionsRequest as GetPermissionsRequest$1, GetPermissionsResponse as GetPermissionsResponse$1, UpdatePermissionsRequest as UpdatePermissionsRequest$1, UpdatePermissionsResponse as UpdatePermissionsResponse$1, AddSpecialPermissionsRequest as AddSpecialPermissionsRequest$1, AddSpecialPermissionsResponse as AddSpecialPermissionsResponse$1, UpdateSpecialPermissionsRequest as UpdateSpecialPermissionsRequest$1, UpdateSpecialPermissionsResponse as UpdateSpecialPermissionsResponse$1, RemoveSpecialPermissionsRequest as RemoveSpecialPermissionsRequest$1, RemoveSpecialPermissionsResponse as RemoveSpecialPermissionsResponse$1, GetMyPermissionsRequest as GetMyPermissionsRequest$1, GetMyPermissionsResponse as GetMyPermissionsResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

/**
 * Permissions configuration for a data collection, controlling who can perform various operations on its data items.
 * Each operation (read, insert, update, remove) can have a different access level, and additional special permissions can be granted to specific users or roles.
 */
interface DataPermissions {
    /**
     * ID of the data collection to which the permissions apply.
     * @immutable
     * @maxLength 255
     */
    id?: string;
    /** Read items in the specified collection. */
    itemRead?: AccessLevelWithLiterals;
    /** Create new items in the specified collection. */
    itemInsert?: AccessLevelWithLiterals;
    /** Update existing items in the specified collection. */
    itemUpdate?: AccessLevelWithLiterals;
    /** Remove items from the specified collection. */
    itemRemove?: AccessLevelWithLiterals;
}
/** Level of access required to perform an operation. Each level includes the permissions of the levels below it. */
declare enum AccessLevel {
    /** Access level is not set. */
    UNKNOWN = "UNKNOWN",
    /** Any user, including site visitors ([SDK](https://dev.wix.com/docs/sdk/articles/work-with-the-sdk/about-identities#site-visitor) | [REST](https://dev.wix.com/docs/rest/articles/get-started/about-identities#site-visitor)). */
    ANYONE = "ANYONE",
    /** Logged-in user. This includes site members as well as [site collaborators](https://support.wix.com/en/article/inviting-people-to-contribute-to-your-site). */
    SITE_MEMBER = "SITE_MEMBER",
    /** Logged-in user. Site members can only access items they created. */
    SITE_MEMBER_AUTHOR = "SITE_MEMBER_AUTHOR",
    /** Site collaborator with [CMS access](https://support.wix.com/en/article/cms-formerly-content-manager-creating-custom-roles-and-permissions). */
    CMS_EDITOR = "CMS_EDITOR",
    /** Site administrators, users, or roles with special permissions. */
    PRIVILEGED = "PRIVILEGED"
}
/** @enumType */
type AccessLevelWithLiterals = AccessLevel | 'UNKNOWN' | 'ANYONE' | 'SITE_MEMBER' | 'SITE_MEMBER_AUTHOR' | 'CMS_EDITOR' | 'PRIVILEGED';
interface SpecialPermissions extends SpecialPermissionsSubjectOneOf {
    /**
     * ID of the user to which these special permissions apply.
     * @immutable
     * @maxLength 64
     */
    userId?: string;
    /**
     * ID of the policy to which these special permissions apply.
     * @immutable
     * @maxLength 64
     */
    policyId?: string;
    /**
     * ID of the special permission.
     * @format GUID
     * @readonly
     */
    id?: string;
    /** Read items in the specified collection. */
    itemRead?: AccessWithLiterals;
    /** Create new items in the specified collection. */
    itemInsert?: AccessWithLiterals;
    /** Update existing items in the specified collection. */
    itemUpdate?: AccessWithLiterals;
    /** Remove items from the specified collection. */
    itemRemove?: AccessWithLiterals;
}
/** @oneof */
interface SpecialPermissionsSubjectOneOf {
    /**
     * ID of the user to which these special permissions apply.
     * @immutable
     * @maxLength 64
     */
    userId?: string;
    /**
     * ID of the policy to which these special permissions apply.
     * @immutable
     * @maxLength 64
     */
    policyId?: string;
}
declare enum Access {
    /** No special permissions explicitly specified. */
    UNSPECIFIED = "UNSPECIFIED",
    /** Action is explicitly allowed. */
    ALLOWED = "ALLOWED"
}
/** @enumType */
type AccessWithLiterals = Access | 'UNSPECIFIED' | 'ALLOWED';
interface GetPermissionsRequest {
    /**
     * ID of the data collection to retrieve permissions for.
     * @maxLength 256
     */
    dataCollectionId: string;
}
interface GetPermissionsResponse {
    /** Retrieved data permissions for the specified collection. */
    dataPermissions?: DataPermissions;
}
interface UpdatePermissionsRequest {
    /** Data permissions to update. */
    dataPermissions: DataPermissions;
}
interface UpdatePermissionsResponse {
    /** Updated data permissions for the specified collection. */
    dataPermissions?: DataPermissions;
}
interface AddSpecialPermissionsRequest {
    /**
     * ID of the data collection to add special permissions for.
     * @maxLength 256
     */
    dataCollectionId: string;
    /** Special permissions to add. */
    specialPermissions: SpecialPermissions;
}
interface AddSpecialPermissionsResponse {
    /** Added special permissions for the specified user or role. */
    specialPermissions?: SpecialPermissions;
}
interface UpdateSpecialPermissionsRequest {
    /** Special permissions to update. */
    specialPermissions: SpecialPermissions;
}
interface UpdateSpecialPermissionsResponse {
    /** Updated special permissions for the specified user or role. */
    specialPermissions?: SpecialPermissions;
}
interface RemoveSpecialPermissionsRequest {
    /**
     * ID of the special permissions to remove.
     * @format GUID
     */
    specialPermissionsId: string;
}
interface RemoveSpecialPermissionsResponse {
}
interface GetMyPermissionsRequest {
    /**
     * ID of the data collection to check permissions for.
     * @maxLength 256
     */
    dataCollectionId: string;
}
interface GetMyPermissionsResponse {
    /** Whether the current user can read items from the collection. */
    itemRead?: boolean;
    /** Whether the current user can create new items in the collection. */
    itemInsert?: boolean;
    /** Whether the current user can update existing items in the collection. */
    itemUpdate?: boolean;
    /** Whether the current user can remove items from the collection. */
    itemRemove?: boolean;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getPermissions(): __PublicMethodMetaInfo<'GET', {}, GetPermissionsRequest$1, GetPermissionsRequest, GetPermissionsResponse$1, GetPermissionsResponse>;
declare function updatePermissions(): __PublicMethodMetaInfo<'POST', {}, UpdatePermissionsRequest$1, UpdatePermissionsRequest, UpdatePermissionsResponse$1, UpdatePermissionsResponse>;
declare function addSpecialPermissions(): __PublicMethodMetaInfo<'POST', {}, AddSpecialPermissionsRequest$1, AddSpecialPermissionsRequest, AddSpecialPermissionsResponse$1, AddSpecialPermissionsResponse>;
declare function updateSpecialPermissions(): __PublicMethodMetaInfo<'POST', {
    specialPermissionsId: string;
}, UpdateSpecialPermissionsRequest$1, UpdateSpecialPermissionsRequest, UpdateSpecialPermissionsResponse$1, UpdateSpecialPermissionsResponse>;
declare function removeSpecialPermissions(): __PublicMethodMetaInfo<'DELETE', {
    specialPermissionsId: string;
}, RemoveSpecialPermissionsRequest$1, RemoveSpecialPermissionsRequest, RemoveSpecialPermissionsResponse$1, RemoveSpecialPermissionsResponse>;
declare function getMyPermissions(): __PublicMethodMetaInfo<'GET', {}, GetMyPermissionsRequest$1, GetMyPermissionsRequest, GetMyPermissionsResponse$1, GetMyPermissionsResponse>;

export { type __PublicMethodMetaInfo, addSpecialPermissions, getMyPermissions, getPermissions, removeSpecialPermissions, updatePermissions, updateSpecialPermissions };
