import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { GetPermissionsResponse, GetPermissionsApplicationErrors, DataPermissions, UpdatePermissionsResponse, AddSpecialPermissionsOptions, AddSpecialPermissionsResponse, AddSpecialPermissionsApplicationErrors, UpdateSpecialPermissions, UpdateSpecialPermissionsResponse, UpdateSpecialPermissionsApplicationErrors, RemoveSpecialPermissionsApplicationErrors, GetMyPermissionsResponse } from './index.typings.mjs';
export { Access, AccessLevel, ActionEvent, AddSpecialPermissionsRequest, Condition, ConditionOperator, ConditionOperatorOperatorsOneOf, ConditionType, ConditionTypeOfOneOf, ConditionValue, ConditionValueValueOneOf, DependOnOperator, DomainEvent, DomainEventBodyOneOf, Effect, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EnvironmentCondition, EnvironmentConditionConditionOneOf, EqualOperator, ExperimentCondition, ExperimentOperator, GetMyPermissionsRequest, GetPermissionsRequest, JoinedCondition, JoinedConditionOperator, LikeOperator, MigrateCustomRolesRequest, MigrateCustomRolesResponse, PolicyAssigned, PolicyAssignment, PolicyAssignmentUpdated, PolicyAssignmentsUpdated, PolicyAssignmentsUpdatedEventOneOf, PolicyAuthorizationDataUpdated, PolicyCondition, PolicyOwner, PolicyOwnerType, PolicyStatement, PolicyType, PolicyUnassigned, RemoveSpecialPermissionsRequest, RemoveSpecialPermissionsResponse, Resource, ResourcePath, RestoreInfo, SimpleCondition, SimpleConditionOperator, SimpleConditionValue, SimpleConditionValueValueOneOf, SpecialPermissions, SpecialPermissionsSubjectOneOf, Subject, SubjectContext, SubjectContextType, SubjectType, UpdatePermissionsRequest, UpdateSpecialPermissionsRequest } from './index.typings.mjs';

declare function getPermissions$1(httpClient: HttpClient): GetPermissionsSignature;
interface GetPermissionsSignature {
    /**
     * Retrieves the permissions set for a specified data collection.
     * @param - ID of the data collection to retrieve permissions for.
     */
    (dataCollectionId: string): Promise<GetPermissionsResponse & {
        __applicationErrorsType?: GetPermissionsApplicationErrors | undefined;
    }>;
}
declare function updatePermissions$1(httpClient: HttpClient): UpdatePermissionsSignature;
interface UpdatePermissionsSignature {
    /**
     * Updates permissions for the specified data collection.
     *
     * > **Note:** To manage special permissions, call Add Special Permissions ([SDK](https://dev.wix.com/docs/sdk/backend-modules/data/permissions/add-special-permissions) | [REST](https://dev.wix.com/docs/rest/business-solutions/cms/data-permissions/add-special-permissions)), Update Special Permissions ([SDK](https://dev.wix.com/docs/sdk/backend-modules/data/permissions/update-special-permissions) | [REST](https://dev.wix.com/docs/rest/business-solutions/cms/data-permissions/update-special-permissions)), or Remove Special Permissions ([SDK](https://dev.wix.com/docs/sdk/backend-modules/data/permissions/remove-special-permissions) | [REST](https://dev.wix.com/docs/rest/business-solutions/cms/data-permissions/remove-special-permissions)).
     * @param - Data permissions to update.
     */
    (dataPermissions: DataPermissions): Promise<UpdatePermissionsResponse>;
}
declare function addSpecialPermissions$1(httpClient: HttpClient): AddSpecialPermissionsSignature;
interface AddSpecialPermissionsSignature {
    /**
     * Adds special permissions for the specified user or role.
     * @param - ID of the data collection to add special permissions for.
     */
    (dataCollectionId: string, options: AddSpecialPermissionsOptions): Promise<AddSpecialPermissionsResponse & {
        __applicationErrorsType?: AddSpecialPermissionsApplicationErrors | undefined;
    }>;
}
declare function updateSpecialPermissions$1(httpClient: HttpClient): UpdateSpecialPermissionsSignature;
interface UpdateSpecialPermissionsSignature {
    /**
     * Updates special permissions for the specified user or role.
     *
     * > **Note:** Special permissions that aren't explicitly included in the request are set to `UNSPECIFIED`.
     * @param - ID of the special permission.
     */
    (_id: string, specialPermissions: UpdateSpecialPermissions): Promise<UpdateSpecialPermissionsResponse & {
        __applicationErrorsType?: UpdateSpecialPermissionsApplicationErrors | undefined;
    }>;
}
declare function removeSpecialPermissions$1(httpClient: HttpClient): RemoveSpecialPermissionsSignature;
interface RemoveSpecialPermissionsSignature {
    /**
     * Deletes a special permission for the specified user or role.
     * @param - ID of the special permissions to remove.
     */
    (specialPermissionsId: string): Promise<void & {
        __applicationErrorsType?: RemoveSpecialPermissionsApplicationErrors | undefined;
    }>;
}
declare function getMyPermissions$1(httpClient: HttpClient): GetMyPermissionsSignature;
interface GetMyPermissionsSignature {
    /**
     * Retrieves the current user's permissions for the specified data collection.
     * @param - ID of the data collection to check permissions for.
     */
    (dataCollectionId: string): Promise<GetMyPermissionsResponse>;
}

declare const getPermissions: MaybeContext<BuildRESTFunction<typeof getPermissions$1> & typeof getPermissions$1>;
declare const updatePermissions: MaybeContext<BuildRESTFunction<typeof updatePermissions$1> & typeof updatePermissions$1>;
declare const addSpecialPermissions: MaybeContext<BuildRESTFunction<typeof addSpecialPermissions$1> & typeof addSpecialPermissions$1>;
declare const updateSpecialPermissions: MaybeContext<BuildRESTFunction<typeof updateSpecialPermissions$1> & typeof updateSpecialPermissions$1>;
declare const removeSpecialPermissions: MaybeContext<BuildRESTFunction<typeof removeSpecialPermissions$1> & typeof removeSpecialPermissions$1>;
declare const getMyPermissions: MaybeContext<BuildRESTFunction<typeof getMyPermissions$1> & typeof getMyPermissions$1>;

export { AddSpecialPermissionsOptions, AddSpecialPermissionsResponse, DataPermissions, GetMyPermissionsResponse, GetPermissionsResponse, UpdatePermissionsResponse, UpdateSpecialPermissions, UpdateSpecialPermissionsResponse, addSpecialPermissions, getMyPermissions, getPermissions, removeSpecialPermissions, updatePermissions, updateSpecialPermissions };
